#########
Reference
#########

***************
Data structures
***************

.. toctree::
   :maxdepth: 2

Segment
=======

.. autoclass:: pyannote.core.Segment
   :members:
   :special-members:

Timeline
========

.. autoclass:: pyannote.core.Timeline
   :members:
   :special-members:

Annotation
==========

.. autoclass:: pyannote.core.Annotation
   :members:
   :special-members:

.. Scores
.. ======
..
.. .. autoclass:: pyannote.core.Scores
..    :members:
..    :special-members:

SlidingWindow
=============

.. autoclass:: pyannote.core.SlidingWindow
   :members:
   :special-members:

SlidingWindowFeature
====================

.. autoclass:: pyannote.core.SlidingWindowFeature
   :members:
   :special-members:

*************
Visualization
*************

.. automodule:: pyannote.core.notebook
   :members:
   :no-index:
